==> apache-carbondata-1.4.1-source-release.zip: carbondata-parent-1.4.1/core/src/main/java/org/apache/carbondata/core/scan/filter/optimizer/RangeFilterOptmizer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.carbondata.core.scan.filter.optimizer;

import org.apache.carbondata.core.scan.expression.Expression;
import org.apache.carbondata.core.scan.expression.RangeExpressionEvaluator;
import org.apache.carbondata.core.scan.filter.intf.FilterOptimizer;

public class RangeFilterOptmizer implements FilterOptimizer {

  RangeExpressionEvaluator rangeExpEvaluator;

  public RangeFilterOptmizer(Expression filterExpression) {
    this.rangeExpEvaluator = new RangeExpressionEvaluator(filterExpression);

  }

  @Override public Expression optimizeFilter() {
    // Check if Range Filter can be applied.
    // rangeExpEvaluator.rangeExpressionEvaluatorGraphBased(null, null);
    rangeExpEvaluator.rangeExpressionEvaluatorMapBased();
    return this.rangeExpEvaluator.getExpr();
  }
}

==> apache-carbondata-2.0.0-source-release.zip: carbondata-parent-2.0.0/core/src/main/java/org/apache/carbondata/core/scan/filter/optimizer/RangeFilterOptmizer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.carbondata.core.scan.filter.optimizer;

import org.apache.carbondata.core.scan.expression.Expression;
import org.apache.carbondata.core.scan.expression.RangeExpressionEvaluator;
import org.apache.carbondata.core.scan.filter.intf.FilterOptimizer;

public class RangeFilterOptmizer implements FilterOptimizer {

  RangeExpressionEvaluator rangeExpEvaluator;

  public RangeFilterOptmizer(Expression filterExpression) {
    this.rangeExpEvaluator = new RangeExpressionEvaluator(filterExpression);

  }

  @Override
  public Expression optimizeFilter() {
    // Check if Range Filter can be applied.
    // rangeExpEvaluator.rangeExpressionEvaluatorGraphBased(null, null);
    rangeExpEvaluator.rangeExpressionEvaluatorMapBased();
    return this.rangeExpEvaluator.getExpr();
  }
}
